@@ -3,26 +3,33 @@
 #
 
 verbose = 0
-gcc_pendantic = True
+gcc_pendantic = False
+gcc_no_long_long = True
 gcc_warnings_are_errors = True
 gcc_all_warnings = True
 gcc_optimize = False
 
-import os
+import os, sys
 from Pyrex.Utils import replace_suffix
 from Pyrex.Compiler.Errors import PyrexError
 
+version_string = "%s.%s" % sys.version_info[:2]
+
 py_include_dirs = [
-    "/Library/Frameworks/Python.framework/Headers"
+    "/Library/Frameworks/Python.framework/Versions/%s/Headers" % version_string
 ]
 
+os.environ["MACOSX_DEPLOYMENT_TARGET"] = "10.3"
+
 compilers = ["gcc", "g++"]
 compiler_options = \
     "-g -c -fno-strict-aliasing -Wno-long-double -no-cpp-precomp " \
     "-mno-fused-madd -fno-common -dynamic " \
     .split()
 if gcc_pendantic:
-    compiler_options.extend(["-pedantic", "-Wno-long-long"])
+    compiler_options.append("-pedantic")
+if gcc_no_long_long:
+    compiler_options.append("-Wno-long-long")
 if gcc_warnings_are_errors:
     compiler_options.append("-Werror")
 if gcc_all_warnings:
@@ -33,8 +40,11 @@ if gcc_optimize:
 
 linkers = ["gcc", "g++"]
 linker_options = \
-    "-Wl,-F.,-w -bundle -framework Python" \
+    "-Wl,-F.,-w -bundle -undefined dynamic_lookup" \
     .split()
+#linker_options = \
+#	"-Wl,-F.,-w -bundle -framework Python" \
+#	.split()
 
 class CCompilerError(PyrexError):
     pass
